@@ -1,7 +1,7 @@
 import urllib.parse
 from datetime import datetime
 import deprecation
-from json import loads
+from orjson import loads
 from typing import List, Dict, Any, Optional, Tuple, Union, Iterator
 from .util import divide_chunks, json
 from .models import PointSelector, PointDataUpdate, IngestStats, \
@@ -192,7 +192,7 @@ class APIClient(ClientBase):
         point_data = PointData.__pydantic_model__.construct  # type: ignore[attr-defined]
 
         with query_call() as res:
-            for line in res.iter_lines():
+            for line in res.iter_lines(chunk_size=20 * 1024):
                 parsed = loads(line)
                 yield point_data(**parsed)
 
